=====
ig_me
=====

A modern, easy to use, feature-rich ready API wrapper for `Instagram Messaging`_ written in Python.


* Documentation: https://leandcesar.github.io/ig_me/
* GitHub: https://github.com/leandcesar/ig_me/
* PyPI: https://pypi.org/project/ig_me/
* Free and open source software: MIT license


Features
--------

* TODO

Installing
----------

Stable release
~~~~~~~~~~~~~~

To install ig_me, run this command in your terminal:

.. code-block:: console

    $ pip install ig_me

This is the preferred method to install ig_me, as it will always install the most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

From sources
~~~~~~~~~~~~

The sources for ig_me can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/leandcesar/ig_me

Or download the `tarball`_:

.. code-block:: console

    $ curl -OJL https://github.com/leandcesar/ig_me/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install

Useful Links
------------

* `Instagram Messaging with the Messenger Platform - Getting Started`_

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.


.. _`Instagram Messaging`: https://developers.facebook.com/docs/messenger-platform/instagram/
.. _`pip`: https://pip.pypa.io
.. _`Python installation guide`: http://docs.python-guide.org/en/latest/starting/installation/
.. _`Github repo`: https://github.com/leandcesar/ig_me
.. _`tarball`: https://github.com/leandcesar/ig_me/tarball/master
.. _`Instagram Messaging with the Messenger Platform - Getting Started`: https://developers.facebook.com/docs/messenger-platform/instagram/get-started
.. _`Cookiecutter`: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
